==> cmake_1.8.2.1.orig.tar.gz: cmake-1.8.2.1/Modules/Platform/IRIX64.cmake <==
SET(CMAKE_DL_LIBS "")
SET(CMAKE_SHARED_LIBRARY_CREATE_C_FLAGS "-shared -rdata_shared")
SET(CMAKE_SHARED_LIBRARY_CREATE_CXX_FLAGS "-shared -rdata_shared") 
SET(CMAKE_SHARED_LIBRARY_RUNTIME_FLAG "-Wl,-rpath,")       # -rpath
SET(CMAKE_SHARED_LIBRARY_RUNTIME_FLAG_SEP "")   # : or empty
IF(NOT CMAKE_COMPILER_IS_GNUCXX)
  # Set default flags init.
  SET(CMAKE_C_FLAGS_INIT "")
  SET(CMAKE_CXX_FLAGS_INIT "")
  SET(CMAKE_EXE_LINKER_FLAGS_INIT "")
  SET(CMAKE_SHARED_LINKER_FLAGS_INIT "")
  SET(CMAKE_MODULE_LINKER_FLAGS_INIT "")
  
  # If no -o32, -n32, or -64 flag is given, set a reasonable default.
  IF("$ENV{CFLAGS} $ENV{CXXFLAGS} $ENV{LDFLAGS}" MATCHES "-([no]32|64)")
  ELSE("$ENV{CFLAGS} $ENV{CXXFLAGS} $ENV{LDFLAGS}" MATCHES "-([no]32|64)")
    # Check if this is a 64-bit CMake.
    IF(CMAKE_FILE_SELF MATCHES "^CMAKE_FILE_SELF$")
      EXEC_PROGRAM(file ARGS ${CMAKE_COMMAND} OUTPUT_VARIABLE CMAKE_FILE_SELF)
      SET(CMAKE_FILE_SELF "${CMAKE_FILE_SELF}" CACHE INTERNAL
        "Output of file command on ${CMAKE_COMMAND}.")
    ENDIF(CMAKE_FILE_SELF MATCHES "^CMAKE_FILE_SELF$")
    
    # Set initial flags to match cmake executable.
    IF(CMAKE_FILE_SELF MATCHES " 64-bit ")
      SET(CMAKE_C_FLAGS_INIT "-64")
      SET(CMAKE_CXX_FLAGS_INIT "-64")
      SET(CMAKE_EXE_LINKER_FLAGS_INIT "-64")
      SET(CMAKE_SHARED_LINKER_FLAGS_INIT "-64")
      SET(CMAKE_MODULE_LINKER_FLAGS_INIT "-64")
    ENDIF(CMAKE_FILE_SELF MATCHES " 64-bit ")
  ENDIF("$ENV{CFLAGS} $ENV{CXXFLAGS} $ENV{LDFLAGS}" MATCHES "-([no]32|64)")
  
  # Set remaining defaults.
  SET(CMAKE_CXX_CREATE_STATIC_LIBRARY
      "<CMAKE_CXX_COMPILER> -ar -o <TARGET> <OBJECTS>")
  SET (CMAKE_CXX_FLAGS_DEBUG_INIT "-g")
  SET (CMAKE_CXX_FLAGS_MINSIZEREL_INIT "-O3")
  SET (CMAKE_CXX_FLAGS_RELEASE_INIT "-O2")
  SET (CMAKE_CXX_FLAGS_RELWITHDEBINFO_INIT "-O2")
ENDIF(NOT CMAKE_COMPILER_IS_GNUCXX)

# set up for gcc if the compiler is gcc
INCLUDE(${CMAKE_ROOT}/Modules/Platform/gcc.cmake)

==> cmake_2.0.5.orig.tar.gz: cmake-2.0.5/Modules/Platform/IRIX64.cmake <==
SET(CMAKE_DL_LIBS "")
SET(CMAKE_SHARED_LIBRARY_CREATE_C_FLAGS "-shared -rdata_shared")
SET(CMAKE_SHARED_LIBRARY_CREATE_CXX_FLAGS "-shared -rdata_shared") 
SET(CMAKE_SHARED_LIBRARY_RUNTIME_FLAG "-Wl,-rpath,")       # -rpath
SET(CMAKE_SHARED_LIBRARY_RUNTIME_FLAG_SEP "")   # : or empty
SET(CMAKE_SHARED_LIBRARY_SONAME_C_FLAG "-Wl,-soname,")
SET(CMAKE_SHARED_LIBRARY_SONAME_CXX_FLAG "-Wl,-soname,")
IF(NOT CMAKE_COMPILER_IS_GNUCXX)
  # Set default flags init.
  SET(CMAKE_C_FLAGS_INIT "")
  SET(CMAKE_CXX_FLAGS_INIT "")
  SET(CMAKE_EXE_LINKER_FLAGS_INIT "")
  SET(CMAKE_SHARED_LINKER_FLAGS_INIT "")
  SET(CMAKE_MODULE_LINKER_FLAGS_INIT "")
  
  # If no -o32, -n32, or -64 flag is given, set a reasonable default.
  IF("$ENV{CFLAGS} $ENV{CXXFLAGS} $ENV{LDFLAGS}" MATCHES "-([no]32|64)")
  ELSE("$ENV{CFLAGS} $ENV{CXXFLAGS} $ENV{LDFLAGS}" MATCHES "-([no]32|64)")
    # Check if this is a 64-bit CMake.
    IF(CMAKE_FILE_SELF MATCHES "^CMAKE_FILE_SELF$")
      EXEC_PROGRAM(file ARGS ${CMAKE_COMMAND} OUTPUT_VARIABLE CMAKE_FILE_SELF)
      SET(CMAKE_FILE_SELF "${CMAKE_FILE_SELF}" CACHE INTERNAL
        "Output of file command on ${CMAKE_COMMAND}.")
    ENDIF(CMAKE_FILE_SELF MATCHES "^CMAKE_FILE_SELF$")
    
    # Set initial flags to match cmake executable.
    IF(CMAKE_FILE_SELF MATCHES " 64-bit ")
      SET(CMAKE_C_FLAGS_INIT "-64")
      SET(CMAKE_CXX_FLAGS_INIT "-64")
      SET(CMAKE_EXE_LINKER_FLAGS_INIT "-64")
      SET(CMAKE_SHARED_LINKER_FLAGS_INIT "-64")
      SET(CMAKE_MODULE_LINKER_FLAGS_INIT "-64")
    ENDIF(CMAKE_FILE_SELF MATCHES " 64-bit ")
  ENDIF("$ENV{CFLAGS} $ENV{CXXFLAGS} $ENV{LDFLAGS}" MATCHES "-([no]32|64)")
  
  # Set remaining defaults.
  SET(CMAKE_CXX_CREATE_STATIC_LIBRARY
      "<CMAKE_CXX_COMPILER> -ar -o <TARGET> <OBJECTS>")
  SET (CMAKE_CXX_FLAGS_DEBUG_INIT "-g")
  SET (CMAKE_CXX_FLAGS_MINSIZEREL_INIT "-O3")
  SET (CMAKE_CXX_FLAGS_RELEASE_INIT "-O2")
  SET (CMAKE_CXX_FLAGS_RELWITHDEBINFO_INIT "-O2")
ENDIF(NOT CMAKE_COMPILER_IS_GNUCXX)

# set up for gcc if the compiler is gcc
INCLUDE(${CMAKE_ROOT}/Modules/Platform/gcc.cmake)
